<?php

namespace Drupal\Tests\responsive_image_preload\Functional;

/**
 * Contains test cases for complex responsive image style configurations.
 *
 * @group responsive_image_preload
 */
class ResponsiveImagePreloadWebpTest extends ResponsiveImagePreloadBrowserTestBase {

  /**
   * {@inheritdoc}
   *
   * This is required because the webp module does not define a config schema.
   */
  protected $strictConfigSchema = FALSE;

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'entity_test',
    'breakpoint',
    'image',
    'responsive_image',
    'responsive_image_preload',
    'responsive_image_preload_test',
    'webp',
  ];

  /**
   * Tests that correct preloads are generated in a variety of configurations.
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   *   This should never happen under normal circumstances.
   * @throws \Drupal\Core\Entity\EntityMalformedException
   *   This should never happen under normal circumstances.
   */
  public function testResponsiveImageWebpPreload() {
    $this->drupalLogin($this->createUser([], NULL, TRUE));

    // Test case with no expected preloads.
    $this->setFormatterSettings('test1', TRUE);
    $this->drupalGet($this->entity->toUrl());

    $page = $this->getSession()->getPage();
    $preloads = $page->findAll('css', 'link[rel="preload"]');

    foreach ($preloads as $preload) {
      static::assertEquals('image/webp', $preload->getAttribute('type'));
    }
  }

}
